@@ -1,7 +1,7 @@
 package Dancer2::Plugin::OpenTelemetry;
 # ABSTRACT: Use OpenTelemetry in your Dancer2 app
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use strict;
 use warnings;
@@ -112,10 +112,7 @@ sub BUILD ( $plugin, @ ) {
                 my $span = otel_span_from_context;
                 my $code = $res->status;
 
-                if ($code < 400) {
-                    $span->set_status(SPAN_STATUS_OK );
-                }
-                elsif ($code >= 500) {
+                if ($code >= 500) {
                     $span->set_status(SPAN_STATUS_ERROR);
                 }
 
